@@ -164,7 +164,7 @@ class GracieBaseAPI(GracieAPIResponseError, GracieError, GracieAuthError, Gracie
                 files = self._prepare_files_for_upload(params['files'])
                 del params['files']
 
-        api_url = '%s://%s:%s%s' % (self._http_protocol, self._gracie_host, self._port, api)
+        api_url = '%s://%s:%s%s%s' % (self._http_protocol, self._gracie_host, self._port, self._api_prefix, api)
 
         if 'post' in actions:
             session_action = self._session.post
@@ -255,6 +255,7 @@ class GracieAPI(GracieApiClassLoader, GracieBaseAPI):
     _http_protocol = 'https'
     _proxies = None
     _download_location = None
+    _api_prefix = ''
 
     _class_loader = None
     _api_controllers = []
@@ -270,7 +271,8 @@ class GracieAPI(GracieApiClassLoader, GracieBaseAPI):
                  wait_for_task_complete=True,
                  remove_task_data_on_complete=True,
                  proxies=None,
-                 download_file_location=None):
+                 download_file_location=None,
+                 api_prefix=None):
 
         self._gracie_host = host
         self._port = port
@@ -292,9 +294,12 @@ class GracieAPI(GracieApiClassLoader, GracieBaseAPI):
 
         self._verify_ssl = verify_ssl
 
+        if isinstance(api_prefix, str):
+            self._api_prefix = api_prefix
+
         GracieBaseAPI.__init__(self)
         GracieApiClassLoader.__init__(self, CONTROLLERS_CLASSES_PATH)
-        GracieSSOAuth.__init__(self, sso_host, login_name, login_password)
+        GracieSSOAuth.__init__(self, sso_host, login_name, login_password, verify_ssl)
 
     @property
     def wait_for_task_complete(self):
